==> apache-roller-6.0.2-rc2-source.tar.gz: roller-weblogger-6.0.2-source/app/src/main/java/org/apache/roller/weblogger/ui/core/plugins/UIPluginManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  The ASF licenses this file to You
 * under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.  For additional information regarding
 * copyright in this work, please see the NOTICE file in the top level
 * directory of this distribution.
 */

package org.apache.roller.weblogger.ui.core.plugins;

import java.util.List;


/**
 * Plugin management for UI layer plugins.
 */
public interface UIPluginManager {
    
    /**
     * Get the list of all configured WeblogEntryEditors.
     *
     * @return List of all configure WeblogEntryEditor objects.
     */
    List getWeblogEntryEditors();
    
    
    /**
     * Get a WeblogEntryEditor by name.  If the specified editor cannot be found
     * or the id is null, then the default editor should be returned.
     *
     * @param id The id of the desired WeblogEntryEditor.
     * @return The WeblogEntry editor desired, or the default editor if the
     *      desired editor could not be found.
     */
    WeblogEntryEditor getWeblogEntryEditor(String id);
    
}

==> apache-roller-6.1.3-source.tar.gz: roller-weblogger-6.1.3-source/app/src/main/java/org/apache/roller/weblogger/ui/core/plugins/UIPluginManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  The ASF licenses this file to You
 * under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.  For additional information regarding
 * copyright in this work, please see the NOTICE file in the top level
 * directory of this distribution.
 */

package org.apache.roller.weblogger.ui.core.plugins;

import java.util.List;


/**
 * Plugin management for UI layer plugins.
 */
public interface UIPluginManager {
    
    /**
     * Get the list of all configured WeblogEntryEditors.
     *
     * @return List of all configure WeblogEntryEditor objects.
     */
    List<WeblogEntryEditor> getWeblogEntryEditors();
    
    
    /**
     * Get a WeblogEntryEditor by name.  If the specified editor cannot be found
     * or the id is null, then the default editor should be returned.
     *
     * @param id The id of the desired WeblogEntryEditor.
     * @return The WeblogEntry editor desired, or the default editor if the
     *      desired editor could not be found.
     */
    WeblogEntryEditor getWeblogEntryEditor(String id);
    
}
